@@ -4,4 +4,7 @@ from liquepy import element
 from liquepy import motion
 from liquepy import sra
 from liquepy import num
-from liquepy.functions import *
\ No newline at end of file
+from liquepy.functions import *
+from liquepy import fig
+from liquepy import __about__
+from liquepy import spatial
